==> nextcloud-19.0.4.tgz: nextcloud/apps/updatenotification/l10n/da.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er tilgængelig. Få mere information om hvordan du opdaterer.",
    "Channel updated" : "Kanal opdateret",
    "Update notifications" : "Opdaterings notifikationer",
    "The update server could not be reached since %d days to check for new updates." : "Har ikke været forbundet til opdateringsserveren i %d dage for at tjekke efter nye opdateringer.",
    "Please check the Nextcloud and server log files for errors." : "Tjek venligst Nextcloud server log for fejl.",
    "Update to %1$s is available." : "Opdatering til %1$s er tilgængelig.",
    "Update for %1$s to version %2$s is available." : "Opdatering af %1$s til version %2$s er tilgængelig.",
    "Update for {app} to version %s is available." : "Opdatering af {app} til version %s er tilgængelig.",
    "View in store" : "Se i butik",
    "Apps with available updates" : "Apps med opdateringer",
    "Open updater" : "Åbn for opdatering",
    "Download now" : "Hent nu",
    "The update check is not yet finished. Please refresh the page." : "Opdateringstjek er ikke færdigt. Genindlæs venligst siden.",
    "Your version is up to date." : "Du har seneste version.",
    "A non-default update server is in use to be checked for updates:" : "En ikke standard opdateringsserver bliver brugt for at tjekke efter opdateringer:",
    "Update channel:" : "Opdatér kanal:",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Bemærk at efter en ny udgivelse kan det tage noget tid før den bliver vist her. Vi udruller nye opdateringer spredt ud og nogle gange springer man versioner over hvis der bliver fundet fejl i dem.",
    "Notify members of the following groups about available updates:" : "Meddel brugere fra følgende gruppe om tilgængelige opdateringer: ",
    "Only notification for app updates are available." : "Kun notifikation for app opdateringer tilgængelige.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valgte kanal lave dedikerede notifikationer for serveren ligegyldige.",
    "The selected update channel does not support updates of the server." : "Den valgte opdateringskanal understøtter ikke opdatering af serveren.",
    "View changelog" : "Se ændringslog",
    "Beta" : "Beta"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/updatenotification/l10n/da.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er tilgængelig. Få mere information om hvordan du opdaterer.",
    "Channel updated" : "Kanal opdateret",
    "Update notifications" : "Opdaterings notifikationer",
    "The update server could not be reached since %d days to check for new updates." : "Har ikke været forbundet til opdateringsserveren i %d dage for at tjekke efter nye opdateringer.",
    "Please check the Nextcloud and server log files for errors." : "Tjek venligst Nextcloud server log for fejl.",
    "Update to %1$s is available." : "Opdatering til %1$s er tilgængelig.",
    "Update for %1$s to version %2$s is available." : "Opdatering af %1$s til version %2$s er tilgængelig.",
    "Update for {app} to version %s is available." : "Opdatering af {app} til version %s er tilgængelig.",
    "View in store" : "Se i butik",
    "Apps with available updates" : "Apps med opdateringer",
    "Open updater" : "Åbn for opdatering",
    "Download now" : "Hent nu",
    "The update check is not yet finished. Please refresh the page." : "Opdateringstjek er ikke færdigt. Genindlæs venligst siden.",
    "Your version is up to date." : "Du har seneste version.",
    "A non-default update server is in use to be checked for updates:" : "En ikke standard opdateringsserver bliver brugt for at tjekke efter opdateringer:",
    "Update channel:" : "Opdatér kanal:",
    "Notify members of the following groups about available updates:" : "Meddel brugere fra følgende gruppe om tilgængelige opdateringer: ",
    "Only notification for app updates are available." : "Kun notifikation for app opdateringer tilgængelige.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valgte kanal lave dedikerede notifikationer for serveren ligegyldige.",
    "The selected update channel does not support updates of the server." : "Den valgte opdateringskanal understøtter ikke opdatering af serveren.",
    "View changelog" : "Se ændringslog",
    "Beta" : "Beta",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Bemærk at efter en ny udgivelse kan det tage noget tid før den bliver vist her. Vi udruller nye opdateringer spredt ud og nogle gange springer man versioner over hvis der bliver fundet fejl i dem."
},
"nplurals=2; plural=(n != 1);");
